claudeconfig

package
v0.5.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 26, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Layout

type Layout struct {
	ConfigDir   string
	FakeHomeDir string
}

Layout describes the isolated Claude runtime layout goYoke manages.

func Prepare

func Prepare(opts PrepareOptions) (Layout, error)

Prepare stages the embedded public Claude config into a goYoke-managed runtime directory and returns the config dir plus the fake HOME directory that Claude subprocesses should use.

type PrepareOptions

type PrepareOptions struct {
	EmbeddedFS fs.FS
	ConfigDir  string
	NativeHome string
}

PrepareOptions controls how the isolated Claude runtime tree is created.

Jump to