Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Layout ¶
Layout describes the isolated Claude runtime layout goYoke manages.
func Prepare ¶
func Prepare(opts PrepareOptions) (Layout, error)
Prepare stages the embedded public Claude config into a goYoke-managed runtime directory and returns the config dir plus the fake HOME directory that Claude subprocesses should use.
Click to show internal directories.
Click to hide internal directories.